Peak Signal-to-Noise Ratio (PSNR)
=================================

.. automodule:: viqa.fr_metrics.psnr
    :exclude-members: PSNR
   
   
.. rubric:: Classes

.. currentmodule:: viqa.fr_metrics.psnr

.. autosummary::
    :toctree: generated/
    :template: class.rst

    PSNR